searchData={"content_type":"text/markdown","items":[{"doc":"`StickerClient` is a library for interfacing with the Signal Stickers API.","ref":"StickerClient.html","title":"StickerClient","type":"module"},{"doc":"Download operations work primarily on two elements, Packs and Stickers. These are \nrepresented as `StickerClient.Pack` and `StickerClient.Sticker` respectively. A Pack\nstruct contains information about the sticker pack. It is a translated view of Signals \nmanifest [protobuf definition](https://signal.art/addstickers/Stickers.proto). The Pack\nmay or may not contain sticker definitions with content, depending on how the API is called. \n\nMost likely, manifests will be downloaded alongside their sticker content in full. The \nPack ID and Pack Key can be provided individually, or parsed from a valid URL. \n\n    iex(1)> StickerClient.Downloader.download_pack(\"https://signal.art/addstickers/#pack_id=45bdc863f62e6a2548052e0a0c4cb153&pack_key=9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    {:ok,\n     %StickerClient.Pack{\n       title: \"oh my frog by ilaso\",\n       author: \"https://t.me/addstickers/ohmyfrog_ilaso\",\n       cover: %StickerClient.Protos.Pack.Sticker{\n         id: 0,\n         emoji: nil,\n         __unknown_fields__: []\n       },\n       stickers: [\n         %StickerClient.Sticker{\n           id: 0,\n           emoji: \"👍\",\n           data:  >\n         },\n         %StickerClient.Sticker{\n           id: 1,\n           emoji: \"🐸\",\n           data:  >\n         },\n         %StickerClient.Sticker{\n           id: 2,\n           emoji: \"🐸\",\n           data:  >\n         },\n         %StickerClient.Sticker{\n           id: 3,\n           emoji: \"🐸\",\n           data:  >\n         },\n         %StickerClient.Sticker{\n           id: 4,\n           emoji: \"🐸\",\n           data:  >\n         } \n         ... CONTINUED\n         \nIt is possible, using the downloader, to only retrieve a manifest: \n\n\n    iex> StickerClient.Downloader.download_manifest(\"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    {:ok,\n     %StickerClient.Pack{\n       title: \"oh my frog by ilaso\",\n       author: \"https://t.me/addstickers/ohmyfrog_ilaso\",\n       cover: %StickerClient.Protos.Pack.Sticker{\n         id: 0,\n         emoji: nil,\n         __unknown_fields__: []\n       },\n       stickers: [\n         %StickerClient.Sticker{id: 0, emoji: \"👍\", data: nil},\n         %StickerClient.Sticker{id: 1, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 2, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 3, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 4, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 5, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 6, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 7, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 8, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 9, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 10, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 11, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 12, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 13, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 14, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 15, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 16, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 17, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 18, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 19, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 20, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 21, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 22, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 23, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 24, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 25, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 26, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 27, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 28, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 29, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 30, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 31, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 32, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 33, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 34, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 35, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 36, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 37, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 38, emoji: \"🐸\", data: nil},\n         %StickerClient.Sticker{id: 39, emoji: \"🐸\", data: nil}\n       ]\n     }}\n\nIn the above example, the sticker data is `nil`. We have retrieved only the representation of the stickers, not the sticker data. \n\nSticker data can be downloaded on a per-sticker-basis by providing either the ID or the `StickerClient.Sticker` struct to \n`StickerClient.Downloader.download_sticker/3`. If an ID is provided only, the emoji will not be populated, as this comes from the manifest:\n\n    iex> StickerClient.Downloader.download_sticker(10, \"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    {:ok,\n     %StickerClient.Sticker{\n       id: 10,\n       emoji: nil,\n       data:  >\n     }}\n\nEnumerables of integers IDs or `StickerClient.Sticker`'s can also be provided: \n\n    iex> StickerClient.Downloader.download_stickers(1..3, \"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    [\n      %StickerClient.Sticker{\n        id: 1,\n        emoji: nil,\n        data:  >\n      },\n      %StickerClient.Sticker{\n        id: 2,\n        emoji: nil,\n        data:  >\n      },\n      %StickerClient.Sticker{\n        id: 3,\n        emoji: nil,\n        data:  >\n      }\n    ]\n\nAs previously mentioned, `StickerClient.Sticker` structs are also valid input, and thus manifest definitions can be \nused to retrieve some or all of the stickers they define. If retrieved in this manner, the emoji field will be \npopulated alongside ID and the sticker data:\n\n    iex> {:ok, manifest} = StickerClient.Downloader.download_manifest(\"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    iex> manifest.stickers |> Enum.take(3) |> StickerClient.Downloader.download_stickers(\"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    [\n      %StickerClient.Sticker{\n        id: 0,\n        emoji: \"👍\",\n        data:  >\n      },\n      %StickerClient.Sticker{\n        id: 1,\n        emoji: \"🐸\",\n        data:  >\n      },\n      %StickerClient.Sticker{\n        id: 2,\n        emoji: \"🐸\",\n        data:  >\n      }\n    ]","ref":"StickerClient.html#module-downloading","title":"Downloading - StickerClient","type":"module"},{"doc":"`StickerClient.Crypto` provides cryptographic utilities required when interacting with\nthe Signal Sticker API.","ref":"StickerClient.Crypto.html","title":"StickerClient.Crypto","type":"module"},{"doc":"Attempts to decrypt the given binary by first deriving AES and HMAC keys \nfrom the pack key, then decrypting the content using the derived keys\n\n\nThis method is a convenience to avoid a call to `StickerClient.Crypto.derive_keys/1` \nyourself, but is effectively the same. If decrypting multiple binaries which are all from\nthe same pack, consider instead deriving the keys once and passing those keys to \n`StickerClient.Crypto.decrypt_content/3` instead.","ref":"StickerClient.Crypto.html#decrypt_content/2","title":"StickerClient.Crypto.decrypt_content/2","type":"function"},{"doc":"Attempts to decrypt the given binary using the provided AES key for encryption \nand HMAC key for integrity\n\n\nThis method should be used alongside `StickerClient.Crypto.derive_keys/1` to \nderive the keys once, then decrypting and validating all content by providing \nthose keys, as well as the encrypted content, to this method.","ref":"StickerClient.Crypto.html#decrypt_content/3","title":"StickerClient.Crypto.decrypt_content/3","type":"function"},{"doc":"Derives the AES (encryption) and HMAC (integrity) keys from the \nprovided pack key. \n\n\nTypically not called directly as part of pack downloading or uploading, this \nfunction allows for the keys to be derived outside of the crypto operations \non a per element (manifest|sticker) basis. Useful to prevent re-calculation of \nkeys per element.","ref":"StickerClient.Crypto.html#derive_keys/1","title":"StickerClient.Crypto.derive_keys/1","type":"function"},{"doc":"iex> StickerClient.Crypto.derive_keys(\"15ec8868cec15c35764af51e09951fc15b548d1dfc1267d0f56bcf7e339b7d09\")\n    {:ok,\n    { >,\n     >}}\n\n    iex(1)> StickerClient.Crypto.derive_keys(\"15e4af51e09951fc15b548d1dfc1267d0f56bcf7e339b7d\")\n    {:error, %StickerClient.Exception{message: \"Invalid key size. Expected 64 bytes.\"}}","ref":"StickerClient.Crypto.html#derive_keys/1-examples","title":"Examples - StickerClient.Crypto.derive_keys/1","type":"function"},{"doc":"`StickerClient.Downloader` is used to download content from the Signal sticker API,\nincluding Pack information and Stickers.","ref":"StickerClient.Downloader.html","title":"StickerClient.Downloader","type":"module"},{"doc":"Download a manifest given a Pack ID and Pack Key. \n\nThe downloaded manifest will not contain Sticker data, only Sticker metadata.","ref":"StickerClient.Downloader.html#download_manifest/2","title":"StickerClient.Downloader.download_manifest/2","type":"function"},{"doc":"Download a pack from the given valid URL, optionally providing concurrency settings.\n\nThe URL takes the format of `https://signal.arwt/addstickers/#pack_id=PACK_ID&pack_key=PACK_KEY`.","ref":"StickerClient.Downloader.html#download_pack/2","title":"StickerClient.Downloader.download_pack/2","type":"function"},{"doc":"Download a pack from the given Pack Key and Pack ID, providing concurrency settings.","ref":"StickerClient.Downloader.html#download_pack/3","title":"StickerClient.Downloader.download_pack/3","type":"function"},{"doc":"Download a sticker, providing either a sticker ID as integer, or, a `StickerClient.Sticker` with a set ID. \n\nThe downloaded sticker will not have metadata such as the associated emoji if a \nnumeric ID is given, or if the provided `StickerClient.Sticker` also does not contain\nmetadata.","ref":"StickerClient.Downloader.html#download_sticker/3","title":"StickerClient.Downloader.download_sticker/3","type":"function"},{"doc":"Downloads multiple stickers, providing an enumerable containing sticker IDs as integers, or,`StickerClient.Sticker`'s, with set IDs\n\nThe downloaded sticker will not have metadata such as the associated emoji if a \nnumeric ID is given, or if the provided `StickerClient.Sticker` also does not contain\nmetadata.","ref":"StickerClient.Downloader.html#download_stickers/4","title":"StickerClient.Downloader.download_stickers/4","type":"function"},{"doc":"`StickerClient.Mapper` is a utility module for converting Protobuf Structs to StickerClient defined Structs.","ref":"StickerClient.Mapper.html","title":"StickerClient.Mapper","type":"module"},{"doc":"Convert a Protobuf defined Pack and list of Stickers to a `StickerClient.Pack`.","ref":"StickerClient.Mapper.html#map_pack/2","title":"StickerClient.Mapper.map_pack/2","type":"function"},{"doc":"Convert a Protobuf defined sticker Struct to a `StickerClient.Sticker` without data.","ref":"StickerClient.Mapper.html#map_sticker/1","title":"StickerClient.Mapper.map_sticker/1","type":"function"},{"doc":"Convert a Protobuf defined sticker Struct to a `StickerClient.Sticker` with data.","ref":"StickerClient.Mapper.html#map_sticker/2","title":"StickerClient.Mapper.map_sticker/2","type":"function"},{"doc":"Represents a Pack returned from the Signal stickers API.","ref":"StickerClient.Pack.html","title":"StickerClient.Pack","type":"module"},{"doc":"","ref":"StickerClient.Pack.html#t:t/0","title":"StickerClient.Pack.t/0","type":"type"},{"doc":"Represents a Sticker returned from the Signal stickers API.","ref":"StickerClient.Sticker.html","title":"StickerClient.Sticker","type":"module"},{"doc":"","ref":"StickerClient.Sticker.html#t:t/0","title":"StickerClient.Sticker.t/0","type":"type"},{"doc":"`StickerClient.Validator` is a utility module which provides parsing and validation to support `StickerClient`.","ref":"StickerClient.Validator.html","title":"StickerClient.Validator","type":"module"},{"doc":"Attempts to parse an `https://signal.art/addstickers` URL to extract the Pack ID and Key.","ref":"StickerClient.Validator.html#parse_download_url/1","title":"StickerClient.Validator.parse_download_url/1","type":"function"},{"doc":"iex> parse_download_url(\"https://signal.art/addstickers/#pack_id=45bdc863f62e6a2548052e0a0c4cb153&pack_key=9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")\n    {:ok, \"45bdc863f62e6a2548052e0a0c4cb153\", \"9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\"}\n\n    # Typo in pack_key\n    iex> parse_download_url(\"https://signal.art/addstickers/#pack_id=45bdc863f62e6a2548052e0a0c4cb153&pack_ke=9dc85e4d5d65d0b272274e5bd4f047fcda3551e77f89053c06078ace81fa6a41\")  \n    {:error, %StickerClient.Exception{message: \"Invalid format, Pack ID and Key could not be parsed\"}}","ref":"StickerClient.Validator.html#parse_download_url/1-examples","title":"Examples - StickerClient.Validator.parse_download_url/1","type":"function"},{"doc":"","ref":"StickerClient.Exception.html","title":"StickerClient.Exception","type":"exception"},{"doc":"","ref":"StickerClient.Exception.html#new/1","title":"StickerClient.Exception.new/1","type":"function"},{"doc":"","ref":"StickerClient.Exception.html#wrap/1","title":"StickerClient.Exception.wrap/1","type":"function"},{"doc":"","ref":"StickerClient.Exception.html#t:t/0","title":"StickerClient.Exception.t/0","type":"type"}]}